This directory contains notebooks contributed by the BoTorch community.

Unlike BoTorch tutorials, the notebooks here are not subject to strict runtime
limitations. As such, they can be used to demonstrate a method using longer
running experiments or for comparing multiple methods.

Each notebook should include a timestamp of last update, as well as the version
of BoTorch that was used during execution. Each notebook should also list the
GitHub handle of its contributors, who may be asked for help in maintaining &
updating the notebook against future versions for BoTorch and dependencies.

The notebooks are parsed and included in the BoTorch website.
